'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
var vue$1 = require('@headlessui/vue');
var macrameVue3 = require('@macramejs/macrame-vue3');

function getVariant(props, { DEFAULT = 'blue' }) {
    return vue.computed(() => {
        if (props.variant) {
            return props.variant;
        }

        if (props.blue) {
            return 'blue';
        }
        if (props.gray) {
            return 'gray';
        }
        if (props.green) {
            return 'green';
        }
        if (props.yellow) {
            return 'yellow';
        }
        if (props.red) {
            return 'red';
        }

        return DEFAULT;
    });
}

const variants = {
    variant: {
        type: String,
        default: null,
    },
    blue: {
        type: Boolean,
        default: false,
    },
    gray: {
        type: Boolean,
        default: false,
    },
    green: {
        type: Boolean,
        default: false,
    },
    yellow: {
        type: Boolean,
        default: false,
    },
    red: {
        type: Boolean,
        default: false,
    },
};

function getSize(props, { DEFAULT = 'md', only = ['sm', 'md', 'lg'] }) {
    return vue.computed(() => {
        if (props.size) {
            return props.size;
        }

        if (props.sm && only.includes('sm')) {
            return 'sm';
        }
        if (props.md && only.includes('md')) {
            return 'md';
        }
        if (props.lg && only.includes('lg')) {
            return 'lg';
        }

        return DEFAULT;
    });
}

const sizes = {
    size: {
        type: String,
        default: null,
    },
    sm: {
        type: Boolean,
        default: false,
    },
    md: {
        type: Boolean,
        default: false,
    },
    lg: {
        type: Boolean,
        default: false,
    },
};

var script$v = vue.defineComponent({
    props: {
        disabled: {
            default: false,
            type: Boolean,
        },
        text: {
            default: false,
            type: Boolean,
        },
        square: {
            default: false,
            type: Boolean,
        },
        outline: {
            default: false,
            type: Boolean,
        },
        ...variants,
        ...sizes,
    },
    setup(props, { attrs }) {
        const tag = 'href' in attrs ? 'a' : 'button';
        const variant_ = getVariant(props, {});
        const size_ = getSize(props, {});

        return { tag, variant_, size_ };
    },
});

function render$p(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createBlock(vue.resolveDynamicComponent(_ctx.tag), vue.mergeProps({
    class: ["inline-flex items-center justify-center focus:outline-none", {
            'focus:ring': !_ctx.text && !_ctx.disabled,

            'text-lg': _ctx.size_ == 'lg',
            'text-base': _ctx.size_ == 'md',
            'text-xs': _ctx.size_ == 'sm',

            'w-12': _ctx.square && _ctx.size_ == 'lg',
            'w-10': _ctx.square && _ctx.size_ == 'md',
            'w-7': _ctx.square && _ctx.size_ == 'sm',

            'h-12  rounded-lg': _ctx.size_ == 'lg' && !_ctx.text,
            'h-10  rounded-md': _ctx.size_ == 'md' && !_ctx.text,
            'h-7  rounded-sm': _ctx.size_ == 'sm' && !_ctx.text,

            'px-6': _ctx.size_ == 'lg' && !_ctx.square && !_ctx.text,
            'px-5': _ctx.size_ == 'md' && !_ctx.square && !_ctx.text,
            'px-4': _ctx.size_ == 'sm' && !_ctx.square && !_ctx.text,

            'border-gray-500 border text-gray-500 cursor-not-allowed':
                _ctx.disabled && _ctx.outline,
            'bg-gray-300 text-gray-600 cursor-not-allowed':
                _ctx.disabled && !_ctx.outline && !_ctx.text,

            'bg-blue hover:bg-blue-700 active:bg-blue-800 text-white focus:ring-blue-400 shadow':
                _ctx.variant_ == 'blue' && !_ctx.outline && !_ctx.text && !_ctx.disabled,
            'bg-white hover:bg-blue-100 active:bg-blue-300 text-blue hover:text-blue-600 active:text-blue-700 border border-blue focus:ring-blue-400':
                _ctx.variant_ == 'blue' && _ctx.outline && !_ctx.text && !_ctx.disabled,
            'text-blue hover:text-blue-700 active:text-blue-900 border-b border-blue':
                _ctx.variant_ == 'blue' && _ctx.text && !_ctx.disabled,

            'bg-gray-700 hover:bg-gray-800 active:bg-gray-900 focus:ring-gray-400 text-white':
                _ctx.variant_ == 'gray' && !_ctx.outline && !_ctx.text && !_ctx.disabled,
            'bg-white hover:bg-gray-700 hover:text-white active:text-white active:bg-gray-700 border border-gray-700 text-gray-700 focus:ring-gray-400':
                _ctx.variant_ == 'gray' && _ctx.outline && !_ctx.text && !_ctx.disabled,
            'text-gray hover:text-gray-700 active:text-gray-900 border-b border-gray':
                _ctx.variant_ == 'gray' && _ctx.text && !_ctx.disabled,

            'bg-green hover:bg-green-700 active:bg-green-800 focus:ring-green-400 text-white':
                _ctx.variant_ == 'green' && !_ctx.outline && !_ctx.text && !_ctx.disabled,
            'bg-white hover:bg-green-100 active:bg-green-300 text-green hover:text-green-600 active:text-green-700 border border-green focus:ring-green-400':
                _ctx.variant_ == 'green' && _ctx.outline && !_ctx.text && !_ctx.disabled,
            'text-green hover:text-green-700 active:text-green-900 border-b border-green':
                _ctx.variant_ == 'green' && _ctx.text && !_ctx.disabled,

            'bg-red hover:bg-red-500 active:bg-red-600 focus:ring-red-400 text-white':
                _ctx.variant_ == 'red' && !_ctx.outline && !_ctx.text && !_ctx.disabled,
            'bg-white hover:bg-red-100 active:bg-red-300 text-red hover:text-red-600 active:text-red-700 border border-red focus:ring-red-400':
                _ctx.variant_ == 'red' && _ctx.outline && !_ctx.text && !_ctx.disabled,
            'text-red hover:text-red-700 active:text-red-900 border-b border-red':
                _ctx.variant_ == 'red' && _ctx.text && !_ctx.disabled,

            'bg-yellow hover:bg-yellow-700 active:bg-yellow-800 focus:ring-yellow-400 text-white':
                _ctx.variant_ == 'yellow' && !_ctx.outline && !_ctx.text && !_ctx.disabled,
            'bg-white hover:bg-yellow-100 active:bg-yellow-300 text-yellow hover:text-yellow-600 active:text-yellow-700 border border-yellow focus:ring-yellow-400':
                _ctx.variant_ == 'yellow' && _ctx.outline && !_ctx.text && !_ctx.disabled,
            'text-yellow hover:text-yellow-700 active:text-yellow-900 border-b border-yellow':
                _ctx.variant_ == 'yellow' && _ctx.text && !_ctx.disabled,
        }],
    disabled: _ctx.disabled
  }, _ctx.$attrs), {
    default: vue.withCtx(() => [
      vue.renderSlot(_ctx.$slots, "default")
    ]),
    _: 3 /* FORWARDED */
  }, 16 /* FULL_PROPS */, ["class", "disabled"]))
}

script$v.render = render$p;
script$v.__file = "packages/admin-vue3/src/ui/Button.vue";

var script$u = vue.defineComponent({
    props: {
        as: {
            type: String,
            default: 'div',
        },
        variant: variants.variant,
        white: {
            type: Boolean,
            default: false,
        },
        gray: variants.gray,
        size: sizes.size,
        sm: sizes.sm,
        md: sizes.md,
    },
    setup(props, { attrs }) {
        let variant_ = getVariant(props, { DEFAULT: 'white' });
        let size_ = getSize(props, { only: ['sm', 'md'] });
        return { variant_, size_ };
    },
});

function render$o(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createBlock(vue.resolveDynamicComponent(_ctx.as), {
    class: vue.normalizeClass(["rounded-sm p-6", {
            'bg-white shadow': _ctx.variant_ == 'white',
            'bg-gray-300': _ctx.variant_ == 'gray',
            'p-12': _ctx.size_ == 'md',
            'p-8': _ctx.size_ == 'sm',
        }])
  }, {
    default: vue.withCtx(() => [
      vue.renderSlot(_ctx.$slots, "default")
    ]),
    _: 3 /* FORWARDED */
  }, 8 /* PROPS */, ["class"]))
}

script$u.render = render$o;
script$u.__file = "packages/admin-vue3/src/ui/Card.vue";

var script$t = {
    components: { Switch: vue$1.Switch, SwitchGroup: vue$1.SwitchGroup, SwitchLabel: vue$1.SwitchLabel },
    props: {
        label: {
            type: String,
            default: null,
        },
        disabled: {
            type: Boolean,
            default: false,
        },
        modelValue: {
            type: Boolean,
            default: false,
        },
        ...sizes,
        ...variants,
    },

    setup({ disabled, ...props }, { emit }) {
        const size_ = getSize(props, {});
        const variant_ = getVariant(props, {});

        const update = (value) => {
            if (disabled) {
                return;
            }
            emit('update:modelValue', value);
        };

        return { update, size_, variant_ };
    },
};

const _hoisted_1$m = { class: "inline-flex flex-col" };

function render$n(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_SwitchLabel = vue.resolveComponent("SwitchLabel");
  const _component_Switch = vue.resolveComponent("Switch");
  const _component_SwitchGroup = vue.resolveComponent("SwitchGroup");

  return (vue.openBlock(), vue.createBlock(_component_SwitchGroup, null, {
    default: vue.withCtx(() => [
      vue.createElementVNode("div", _hoisted_1$m, [
        vue.createVNode(_component_SwitchLabel, { class: "mr-4" }, {
          default: vue.withCtx(() => [
            vue.renderSlot(_ctx.$slots, "default", {}, () => [
              vue.createTextVNode(vue.toDisplayString($props.label), 1 /* TEXT */)
            ])
          ]),
          _: 3 /* FORWARDED */
        }),
        vue.createVNode(_component_Switch, {
          modelValue: $props.modelValue,
          "onUpdate:modelValue": $setup.update,
          class: vue.normalizeClass([{
                    'bg-gray-500': !$props.modelValue,
                    'bg-blue-500':
                        ($setup.variant_ == null && $props.modelValue) ||
                        ($setup.variant_ == 'blue' && $props.modelValue),

                    'bg-green-500': $setup.variant_ == 'green' && $props.modelValue,

                    'bg-red-500': $setup.variant_ == 'red' && $props.modelValue,

                    'bg-yellow-500': $setup.variant_ == 'yellow' && $props.modelValue,

                    'text-lg': $setup.size_ == 'lg',
                    'text-base': $setup.size_ == 'md' || $setup.size_ == null,
                    'text-xs': $setup.size_ == 'sm',

                    'w-16': $setup.size_ == 'lg',
                    'w-10': $setup.size_ == 'md' || $setup.size_ == null,
                    'w-8': $setup.size_ == 'sm',

                    'h-8 rounded-lg': $setup.size_ == 'lg',
                    'h-5 rounded-md': $setup.size_ == 'md' || $setup.size_ == null,
                    'h-4 rounded-sm': $setup.size_ == 'sm',
                }, "relative inline-flex items-center transition-all rounded-full focus:outline-none focus:ring-4 focus:ring-blue-300"])
        }, {
          default: vue.withCtx(() => [
            vue.createElementVNode("span", {
              class: vue.normalizeClass([{
                        'w-8 h-8': $setup.size_ == 'lg',
                        'w-5 h-5': $setup.size_ == 'md',
                        'w-4 h-4': $setup.size_ == 'sm',

                        'border-blue-500':
                            ($setup.variant_ == 'blue' && $props.modelValue) ||
                            ($setup.variant_ == null && $props.modelValue),
                        'border-green-500': $setup.variant_ == 'green' && $props.modelValue,
                        'border-yellow-500': $setup.variant_ == 'yellow' && $props.modelValue,
                        'border-red-500': $setup.variant_ == 'red' && $props.modelValue,
                        'border-gray-500': !$props.modelValue,

                        'translate-x-0':
                            ($setup.size_ == 'lg' && !$props.modelValue) ||
                            ($setup.size_ == 'md' && !$props.modelValue) ||
                            ($setup.size_ == 'sm' && !$props.modelValue),

                        'translate-x-8': $setup.size_ == 'lg' && $props.modelValue,
                        'translate-x-5': $setup.size_ == 'md' && $props.modelValue,
                        'translate-x-4': $setup.size_ == 'sm' && $props.modelValue,
                    }, "inline-block transition-all transform bg-white border-2 rounded-full"])
            }, null, 2 /* CLASS */)
          ]),
          _: 1 /* STABLE */
        }, 8 /* PROPS */, ["modelValue", "onUpdate:modelValue", "class"])
      ])
    ]),
    _: 3 /* FORWARDED */
  }))
}

script$t.render = render$n;
script$t.__file = "packages/admin-vue3/src/ui/Toggle.vue";

var script$s = vue.defineComponent({
    props: {
        ...variants,
    },
    setup(props, { attrs }) {
        const tag = 'href' in attrs ? 'a' : 'div';
        const variant_ = getVariant(props, {});

        return { tag, variant_ };
    },
});

function render$m(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createBlock(vue.resolveDynamicComponent(_ctx.tag), {
    class: vue.normalizeClass(["inline-flex items-center justify-center px-2 text-sm rounded-xs", {
            'bg-blue text-white ': _ctx.variant_ == 'blue',
            'bg-gray-700 text-white': _ctx.variant_ == 'gray',
            'bg-green text-green-700': _ctx.variant_ == 'green',
            'bg-red text-red-700': _ctx.variant_ == 'red',
            'bg-yellow text-yellow-700': _ctx.variant_ == 'yellow',
        }])
  }, {
    default: vue.withCtx(() => [
      vue.renderSlot(_ctx.$slots, "default")
    ]),
    _: 3 /* FORWARDED */
  }, 8 /* PROPS */, ["class"]))
}

script$s.render = render$m;
script$s.__file = "packages/admin-vue3/src/ui/Badge.vue";

var script$r = /*#__PURE__*/ vue.defineComponent({
    setup(__props) {
        //
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("form", vue.normalizeProps(vue.guardReactiveProps(_ctx.$attrs)), [
                vue.renderSlot(_ctx.$slots, "default")
            ], 16 /* FULL_PROPS */));
        };
    }
});

script$r.__file = "packages/admin-vue3/src/ui/Form.vue";

const _hoisted_1$l = { class: "todo" };
var script$q = /*#__PURE__*/ vue.defineComponent({
    props: {
        label: {
            type: String,
        },
    },
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("span", _hoisted_1$l, [
                vue.renderSlot(_ctx.$slots, "default", {}, () => [
                    vue.createTextVNode(vue.toDisplayString(__props.label), 1 /* TEXT */)
                ])
            ]));
        };
    }
});

script$q.__file = "packages/admin-vue3/src/ui/FormFieldLabel.vue";

const _hoisted_1$k = { class: "todo" };
const _hoisted_2$h = { key: 0 };
var script$p = /*#__PURE__*/ vue.defineComponent({
    props: {
        label: {
            type: String,
        },
        errors: {
            type: [Array, String],
            default: null,
        },
    },
    setup(__props) {
        const props = __props;
        const errorList = vue.computed(() => {
            if (!props.errors) {
                return [];
            }
            if (Array.isArray(props.errors)) {
                return props.errors;
            }
            return [props.errors];
        });
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$k, [
                vue.renderSlot(_ctx.$slots, "label", {}, () => [
                    vue.createVNode(script$q, { label: __props.label }, null, 8 /* PROPS */, ["label"])
                ]),
                vue.renderSlot(_ctx.$slots, "default"),
                (__props.errors)
                    ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_2$h, [
                        (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(vue.unref(errorList), (error, key) => {
                            return (vue.openBlock(), vue.createElementBlock("span", {
                                key: key,
                                class: "text-red"
                            }, vue.toDisplayString(error), 1 /* TEXT */));
                        }), 128 /* KEYED_FRAGMENT */))
                    ]))
                    : vue.createCommentVNode("v-if", true)
            ]));
        };
    }
});

script$p.__file = "packages/admin-vue3/src/ui/FormField.vue";

var script$o = {
    emits: ['close'],
    components: {
        TransitionRoot: vue$1.TransitionRoot,
        TransitionChild: vue$1.TransitionChild,
        Dialog: vue$1.Dialog,
        DialogOverlay: vue$1.DialogOverlay,
        DialogTitle: vue$1.DialogTitle,
    },

    props: {
        open: {
            type: Boolean,
            default: false,
        },
    },

    setup({}, { emit }) {
        function close(val) {
            emit('close', val);
            emit('update:open', val);
        }

        return { close };
    },
};

const _hoisted_1$j = { class: "fixed inset-0 z-50 overflow-y-auto" };
const _hoisted_2$g = { class: "min-h-screen px-4 text-center" };
const _hoisted_3$c = /*#__PURE__*/vue.createElementVNode("span", {
  class: "inline-block h-screen align-middle",
  "aria-hidden": "true"
}, " ​ ", -1 /* HOISTED */);
const _hoisted_4$8 = { class: "inline-block w-full max-w-full p-6 my-8 overflow-hidden text-left align-middle transition-all transform bg-white shadow-xl md:max-w-xl lg:max-w-2xl rounded-xs" };

function render$l(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_DialogOverlay = vue.resolveComponent("DialogOverlay");
  const _component_TransitionChild = vue.resolveComponent("TransitionChild");
  const _component_Dialog = vue.resolveComponent("Dialog");
  const _component_TransitionRoot = vue.resolveComponent("TransitionRoot");

  return (vue.openBlock(), vue.createBlock(_component_TransitionRoot, {
    appear: "",
    show: $props.open,
    as: "template"
  }, {
    default: vue.withCtx(() => [
      vue.createVNode(_component_Dialog, {
        as: "div",
        open: $props.open,
        onClose: $setup.close
      }, {
        default: vue.withCtx(() => [
          vue.createElementVNode("div", _hoisted_1$j, [
            vue.createElementVNode("div", _hoisted_2$g, [
              vue.createVNode(_component_TransitionChild, {
                as: "template",
                enter: "duration-300 ease-out",
                "enter-from": "opacity-0",
                "enter-to": "opacity-100",
                leave: "duration-200 ease-in",
                "leave-from": "opacity-100",
                "leave-to": "opacity-0"
              }, {
                default: vue.withCtx(() => [
                  vue.createVNode(_component_DialogOverlay, { class: "fixed inset-0 bg-gray-900 bg-opacity-50 backdrop-filter backdrop-blur-sm" })
                ]),
                _: 1 /* STABLE */
              }),
              _hoisted_3$c,
              vue.createVNode(_component_TransitionChild, {
                as: "template",
                enter: "duration-300 ease-out",
                "enter-from": "opacity-0 scale-95",
                "enter-to": "opacity-100 scale-100",
                leave: "duration-200 ease-in",
                "leave-from": "opacity-100 scale-100",
                "leave-to": "opacity-0 scale-95"
              }, {
                default: vue.withCtx(() => [
                  vue.createElementVNode("div", _hoisted_4$8, [
                    vue.renderSlot(_ctx.$slots, "default")
                  ])
                ]),
                _: 3 /* FORWARDED */
              })
            ])
          ])
        ]),
        _: 3 /* FORWARDED */
      }, 8 /* PROPS */, ["open", "onClose"])
    ]),
    _: 3 /* FORWARDED */
  }, 8 /* PROPS */, ["show"]))
}

script$o.render = render$l;
script$o.__file = "packages/admin-vue3/src/ui/Modal.vue";

var script$n = vue.defineComponent({
    components: { Switch: vue$1.Switch },
    props: {
        label: {
            type: String,
            default: null,
        },
        disabled: {
            type: Boolean,
            default: false,
        },
        modelValue: {
            type: Boolean,
            default: false,
        },
        ...sizes,
        ...variants,
    },
    setup({ disabled, ...props }, { emit }) {
        const size_ = getSize(props, {});
        const variant_ = getVariant(props, {});
        const update = (value) => {
            if (disabled) {
                return;
            }
            emit('update:modelValue', value);
        };
        return { update, size_, variant_ };
    },
});

const _hoisted_1$i = { class: "inline-flex items-center cursor-pointer" };
const _hoisted_2$f = /*#__PURE__*/vue.createElementVNode("path", {
  fill: "none",
  d: "M0 0h24v24H0z"
}, null, -1 /* HOISTED */);
const _hoisted_3$b = /*#__PURE__*/vue.createElementVNode("path", { d: "M10 15.172l9.192-9.193 1.415 1.414L10 18l-6.364-6.364 1.414-1.414z" }, null, -1 /* HOISTED */);
const _hoisted_4$7 = [
  _hoisted_2$f,
  _hoisted_3$b
];
const _hoisted_5$5 = { class: "pt-1 pl-2" };

function render$k(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Switch = vue.resolveComponent("Switch");

  return (vue.openBlock(), vue.createBlock(_component_Switch, {
    modelValue: _ctx.modelValue,
    "onUpdate:modelValue": _ctx.update,
    as: "template"
  }, {
    default: vue.withCtx(({ checked }) => [
      vue.createElementVNode("div", _hoisted_1$i, [
        vue.createElementVNode("div", {
          class: vue.normalizeClass([{
                    'bg-blue-500':
                        (_ctx.variant_ == null && checked) ||
                        (_ctx.variant_ == 'blue' && checked),
                    'bg-green-500': _ctx.variant_ == 'green' && checked,
                    'bg-red-400': _ctx.variant_ == 'red' && checked,
                    'bg-yellow-400': _ctx.variant_ == 'yellow' && checked,
                    'bg-gray-700': _ctx.variant_ == 'gray' && checked,
                    'bg-white': !checked,

                    'w-6 h-6': _ctx.size_ == 'lg',
                    'w-5 h-5': _ctx.size_ == 'md',
                    'w-4 h-4': _ctx.size_ == 'sm',
                }, "inline-flex items-center justify-center text-white border border-gray-700 rounded-xs"])
        }, [
          (vue.openBlock(), vue.createElementBlock("svg", {
            xmlns: "http://www.w3.org/2000/svg",
            viewBox: "0 0 24 24",
            class: vue.normalizeClass(["fill-current", {
                        'w-4 h-4': _ctx.size_ == 'lg',
                        'w-3 h-3': _ctx.size_ == 'md',
                        'w-2.5 h-2.5': _ctx.size_ == 'sm',
                    }])
          }, _hoisted_4$7, 2 /* CLASS */))
        ], 2 /* CLASS */),
        vue.createElementVNode("label", _hoisted_5$5, [
          vue.renderSlot(_ctx.$slots, "default", {}, () => [
            vue.createTextVNode(vue.toDisplayString(_ctx.label), 1 /* TEXT */)
          ])
        ])
      ])
    ]),
    _: 3 /* FORWARDED */
  }, 8 /* PROPS */, ["modelValue", "onUpdate:modelValue"]))
}

script$n.render = render$k;
script$n.__file = "packages/admin-vue3/src/ui/Checkbox.vue";

var script$m = vue.defineComponent({
    components: {
        FormCheckboxes: macrameVue3.FormCheckboxes,
        FieldTitle: macrameVue3.FieldTitle,
    },
});

function render$j(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_field_title = vue.resolveComponent("field-title");
  const _component_form_checkboxes = vue.resolveComponent("form-checkboxes", true);

  return (vue.openBlock(), vue.createElementBlock("div", null, [
    vue.createVNode(_component_field_title, vue.normalizeProps(vue.guardReactiveProps(_ctx.$attrs)), null, 16 /* FULL_PROPS */),
    vue.createElementVNode("div", null, [
      vue.createVNode(_component_form_checkboxes, vue.normalizeProps(vue.guardReactiveProps(_ctx.$attrs)), null, 16 /* FULL_PROPS */)
    ])
  ]))
}

script$m.render = render$j;
script$m.__file = "packages/admin-vue3/src/ui/FormCheckboxes.vue";

var script$l = vue.defineComponent({
    components: { RadioGroup: vue$1.RadioGroup, RadioGroupLabel: vue$1.RadioGroupLabel, RadioGroupOption: vue$1.RadioGroupOption },
    props: {
        labelKey: {
            type: String,
            default: null,
        },
        valueKey: {
            type: String,
            default: null,
        },
        disabledKey: {
            type: String,
            default: null,
        },
        options: {
            type: Array,
            default: () => [],
        },
        modelValue: {
            type: [String, Number],
            default: null,
        },
    },
    setup(props, { attrs }) {
        const optionValue = (option) => {
            if (props.valueKey === null) {
                return option;
            }
            return option[props.valueKey];
        };
        const optionLabel = (option) => {
            if (props.labelKey === null) {
                return option;
            }
            return option[props.labelKey];
        };
        const isDisabled = (option) => {
            if (props.disabledKey === null) {
                return false;
            }
            return option[props.disabledKey] == true;
        };
        return { optionValue, optionLabel, isDisabled };
    },
});

const _hoisted_1$h = { class: "flex" };
const _hoisted_2$e = { class: "flex items-center w-6 h-6" };
const _hoisted_3$a = /*#__PURE__*/vue.createElementVNode("div", { class: "w-1 h-1 bg-white rounded-lg" }, null, -1 /* HOISTED */);
const _hoisted_4$6 = [
  _hoisted_3$a
];

function render$i(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_RadioGroupLabel = vue.resolveComponent("RadioGroupLabel");
  const _component_RadioGroupOption = vue.resolveComponent("RadioGroupOption");
  const _component_RadioGroup = vue.resolveComponent("RadioGroup", true);

  return (vue.openBlock(), vue.createBlock(_component_RadioGroup, {
    modelValue: _ctx.modelValue,
    "onUpdate:modelValue": _cache[0] || (_cache[0] = $event => (_ctx.$emit('update:modelValue', $event)))
  }, {
    default: vue.withCtx(() => [
      vue.createCommentVNode(" <RadioGroupLabel>Plan</RadioGroupLabel> "),
      (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(_ctx.options, (option) => {
        return (vue.openBlock(), vue.createBlock(_component_RadioGroupOption, {
          as: "template",
          key: _ctx.optionValue(option),
          value: _ctx.optionValue(option),
          disabled: _ctx.isDisabled(option)
        }, {
          default: vue.withCtx(({ checked, disabled }) => [
            vue.createElementVNode("div", _hoisted_1$h, [
              vue.createElementVNode("div", _hoisted_2$e, [
                vue.createElementVNode("div", {
                  class: vue.normalizeClass(["flex items-center justify-center w-3.5 h-3.5 border rounded-lg", {
                            'bg-blue': checked && !disabled,
                            'bg-gray-700': checked && disabled,
                            'border-gray-700': !disabled,
                            'border-gray-600': disabled,
                        }])
                }, _hoisted_4$6, 2 /* CLASS */)
              ]),
              vue.createVNode(_component_RadioGroupLabel, {
                as: "p",
                class: vue.normalizeClass(["flex-1 cursor-pointer", { 'text-gray-600': disabled }])
              }, {
                default: vue.withCtx(() => [
                  vue.createTextVNode(vue.toDisplayString(_ctx.optionLabel(option)), 1 /* TEXT */)
                ]),
                _: 2 /* DYNAMIC */
              }, 1032 /* PROPS, DYNAMIC_SLOTS */, ["class"])
            ])
          ]),
          _: 2 /* DYNAMIC */
        }, 1032 /* PROPS, DYNAMIC_SLOTS */, ["value", "disabled"]))
      }), 128 /* KEYED_FRAGMENT */))
    ]),
    _: 1 /* STABLE */
  }, 8 /* PROPS */, ["modelValue"]))
}

script$l.render = render$i;
script$l.__file = "packages/admin-vue3/src/ui/RadioGroup.vue";

var script$k = vue.defineComponent({
    components: { Button: script$v },
    props: {
        table: {
            type: Object,
            required: true,
        },
    },
});

const _hoisted_1$g = { class: "flex justify-around" };
const _hoisted_2$d = { class: "flex items-stretch space-x-2" };
const _hoisted_3$9 = /*#__PURE__*/vue.createElementVNode("svg", {
  class: "absolute fill-current left-1",
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24",
  width: "24",
  height: "24"
}, [
  /*#__PURE__*/vue.createElementVNode("path", {
    fill: "none",
    d: "M0 0h24v24H0z"
  }),
  /*#__PURE__*/vue.createElementVNode("path", { d: "M10.828 12l4.95 4.95-1.414 1.414L8 12l6.364-6.364 1.414 1.414z" })
], -1 /* HOISTED */);
const _hoisted_4$5 = /*#__PURE__*/vue.createElementVNode("svg", {
  class: "absolute fill-current right-1",
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24",
  width: "24",
  height: "24"
}, [
  /*#__PURE__*/vue.createElementVNode("path", {
    fill: "none",
    d: "M0 0h24v24H0z"
  }),
  /*#__PURE__*/vue.createElementVNode("path", { d: "M10.828 12l4.95 4.95-1.414 1.414L8 12l6.364-6.364 1.414 1.414z" })
], -1 /* HOISTED */);
const _hoisted_5$4 = /*#__PURE__*/vue.createElementVNode("svg", {
  class: "fill-current",
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24",
  width: "24",
  height: "24"
}, [
  /*#__PURE__*/vue.createElementVNode("path", {
    fill: "none",
    d: "M0 0h24v24H0z"
  }),
  /*#__PURE__*/vue.createElementVNode("path", { d: "M10.828 12l4.95 4.95-1.414 1.414L8 12l6.364-6.364 1.414 1.414z" })
], -1 /* HOISTED */);
const _hoisted_6$1 = { class: "flex items-center px-4 space-x-6 text-gray" };
const _hoisted_7$1 = {
  key: 0,
  class: "text-lg"
};
const _hoisted_8$1 = { class: "text-lg font-bold text-blue" };
const _hoisted_9 = {
  key: 5,
  class: "text-lg cursor-pointer"
};
const _hoisted_10 = /*#__PURE__*/vue.createElementVNode("svg", {
  class: "fill-current",
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24",
  width: "24",
  height: "24"
}, [
  /*#__PURE__*/vue.createElementVNode("path", {
    fill: "none",
    d: "M0 0h24v24H0z"
  }),
  /*#__PURE__*/vue.createElementVNode("path", { d: "M13.172 12l-4.95-4.95 1.414-1.414L16 12l-6.364 6.364-1.414-1.414z" })
], -1 /* HOISTED */);
const _hoisted_11 = /*#__PURE__*/vue.createElementVNode("svg", {
  class: "absolute fill-current right-1",
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24",
  width: "24",
  height: "24"
}, [
  /*#__PURE__*/vue.createElementVNode("path", {
    fill: "none",
    d: "M0 0h24v24H0z"
  }),
  /*#__PURE__*/vue.createElementVNode("path", { d: "M13.172 12l-4.95-4.95 1.414-1.414L16 12l-6.364 6.364-1.414-1.414z" })
], -1 /* HOISTED */);
const _hoisted_12 = /*#__PURE__*/vue.createElementVNode("svg", {
  class: "absolute fill-current left-1",
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24",
  width: "24",
  height: "24"
}, [
  /*#__PURE__*/vue.createElementVNode("path", {
    fill: "none",
    d: "M0 0h24v24H0z"
  }),
  /*#__PURE__*/vue.createElementVNode("path", { d: "M13.172 12l-4.95-4.95 1.414-1.414L16 12l-6.364 6.364-1.414-1.414z" })
], -1 /* HOISTED */);

function render$h(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Button = vue.resolveComponent("Button");

  return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$g, [
    vue.createElementVNode("div", _hoisted_2$d, [
      vue.createVNode(_component_Button, {
        outline: "",
        gray: "",
        square: "",
        class: "relative",
        onClick: _cache[0] || (_cache[0] = $event => (_ctx.table.setPage(1))),
        disabled: _ctx.table.currentPage == 1
      }, {
        default: vue.withCtx(() => [
          _hoisted_3$9,
          _hoisted_4$5
        ]),
        _: 1 /* STABLE */
      }, 8 /* PROPS */, ["disabled"]),
      vue.createVNode(_component_Button, {
        outline: "",
        gray: "",
        square: "",
        disabled: _ctx.table.currentPage == 1,
        onClick: _cache[1] || (_cache[1] = $event => (_ctx.table.setPage(_ctx.table.currentPage - 1)))
      }, {
        default: vue.withCtx(() => [
          _hoisted_5$4
        ]),
        _: 1 /* STABLE */
      }, 8 /* PROPS */, ["disabled"]),
      vue.createElementVNode("div", _hoisted_6$1, [
        (_ctx.table.currentPage > 2)
          ? (vue.openBlock(), vue.createElementBlock("span", _hoisted_7$1, " ... "))
          : vue.createCommentVNode("v-if", true),
        (
                        _ctx.table.currentPage == _ctx.table.getLastPage() &&
                        _ctx.table.currentPage > 2
                    )
          ? (vue.openBlock(), vue.createElementBlock("span", {
              key: 1,
              class: "text-lg cursor-pointer",
              onClick: _cache[2] || (_cache[2] = $event => (_ctx.table.setPage(_ctx.table.currentPage - 2)))
            }, vue.toDisplayString(_ctx.table.currentPage - 2), 1 /* TEXT */))
          : vue.createCommentVNode("v-if", true),
        (_ctx.table.currentPage > 1)
          ? (vue.openBlock(), vue.createElementBlock("span", {
              key: 2,
              class: "text-lg cursor-pointer",
              onClick: _cache[3] || (_cache[3] = $event => (_ctx.table.setPage(_ctx.table.currentPage - 1)))
            }, vue.toDisplayString(_ctx.table.currentPage - 1), 1 /* TEXT */))
          : vue.createCommentVNode("v-if", true),
        vue.createElementVNode("span", _hoisted_8$1, vue.toDisplayString(_ctx.table.currentPage), 1 /* TEXT */),
        (_ctx.table.currentPage < _ctx.table.getLastPage())
          ? (vue.openBlock(), vue.createElementBlock("span", {
              key: 3,
              class: "text-lg cursor-pointer",
              onClick: _cache[4] || (_cache[4] = $event => (_ctx.table.setPage(_ctx.table.currentPage + 1)))
            }, vue.toDisplayString(_ctx.table.currentPage + 1), 1 /* TEXT */))
          : vue.createCommentVNode("v-if", true),
        (_ctx.table.currentPage == 1 && _ctx.table.getLastPage() > 2)
          ? (vue.openBlock(), vue.createElementBlock("span", {
              key: 4,
              class: "text-lg cursor-pointer",
              onClick: _cache[5] || (_cache[5] = $event => (_ctx.table.setPage(_ctx.table.currentPage + 2)))
            }, vue.toDisplayString(_ctx.table.currentPage + 2), 1 /* TEXT */))
          : vue.createCommentVNode("v-if", true),
        (_ctx.table.currentPage < _ctx.table.getLastPage() - 1)
          ? (vue.openBlock(), vue.createElementBlock("span", _hoisted_9, " ... "))
          : vue.createCommentVNode("v-if", true)
      ]),
      vue.createVNode(_component_Button, {
        outline: "",
        gray: "",
        square: "",
        disabled: !(_ctx.table.currentPage < _ctx.table.getLastPage()),
        onClick: _cache[6] || (_cache[6] = $event => (_ctx.table.setPage(_ctx.table.currentPage + 1)))
      }, {
        default: vue.withCtx(() => [
          _hoisted_10
        ]),
        _: 1 /* STABLE */
      }, 8 /* PROPS */, ["disabled"]),
      vue.createVNode(_component_Button, {
        outline: "",
        gray: "",
        square: "",
        class: "relative",
        onClick: _cache[7] || (_cache[7] = $event => (_ctx.table.lastPage())),
        disabled: !(_ctx.table.currentPage < _ctx.table.getLastPage())
      }, {
        default: vue.withCtx(() => [
          _hoisted_11,
          _hoisted_12
        ]),
        _: 1 /* STABLE */
      }, 8 /* PROPS */, ["disabled"])
    ])
  ]))
}

script$k.render = render$h;
script$k.__file = "packages/admin-vue3/src/ui/Pagination.vue";

var script$j = vue.defineComponent({
    components: { BaseInput: macrameVue3.Input },
});

function render$g(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_BaseInput = vue.resolveComponent("BaseInput");

  return (vue.openBlock(), vue.createBlock(_component_BaseInput, vue.mergeProps(_ctx.$attrs, { class: "px-4 py-2" }), null, 16 /* FULL_PROPS */))
}

script$j.render = render$g;
script$j.__file = "packages/admin-vue3/src/ui/Input.vue";

var script$i = vue.defineComponent({
    components: { Input: script$j },
    props: {
        table: {
            type: Object,
            required: true,
        },
        placeholder: {
            type: String,
        },
    },
    setup() {
        //
    },
});

const _hoisted_1$f = { class: "flex items-center h-full mb-6 overflow-hidden text-gray-700 border border-gray-700 rounded-md max-w-sm focus-within:text-blue" };
const _hoisted_2$c = /*#__PURE__*/vue.createElementVNode("div", { class: "flex items-center justify-center w-10 h-10 text-white bg-gray-700" }, [
  /*#__PURE__*/vue.createElementVNode("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "-2.5 -2.5 24 24",
    width: "16",
    height: "16",
    preserveAspectRatio: "xMinYMin",
    class: "fill-current icon__icon"
  }, [
    /*#__PURE__*/vue.createElementVNode("path", { d: "M8 14A6 6 0 1 0 8 2a6 6 0 0 0 0 12zm6.32-1.094l3.58 3.58a1 1 0 1 1-1.415 1.413l-3.58-3.58a8 8 0 1 1 1.414-1.414z" })
  ])
], -1 /* HOISTED */);

function render$f(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Input = vue.resolveComponent("Input");

  return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$f, [
    _hoisted_2$c,
    vue.createVNode(_component_Input, {
      modelValue: _ctx.table.search,
      "onUpdate:modelValue": _cache[0] || (_cache[0] = $event => ((_ctx.table.search) = $event)),
      modelModifiers: { debounce: true },
      class: "h-full w-full bg-gray-100 pl-6 text-gray-900 outline-none",
      placeholder: _ctx.placeholder
    }, null, 8 /* PROPS */, ["modelValue", "placeholder"])
  ]))
}

script$i.render = render$f;
script$i.__file = "packages/admin-vue3/src/ui/Search.vue";

var script$h = vue.defineComponent({
    components: {
        Pagination: script$k,
        Search: script$i,
    },
    props: {
        table: {
            type: Object,
            required: true,
        },
        searchPlaceholder: {
            type: String,
        },
    },
    setup({}, {}) {
        //
        return {};
    },
});

const _hoisted_1$e = { class: "w-full bg-white rounded-md shadow pt-9" };
const _hoisted_2$b = { class: "w-full pt-8 pb-4 border-t border-gray-300" };
const _hoisted_3$8 = { class: "inline-flex justify-end w-full pt-4 pr-6 text-gray" };

function render$e(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Search = vue.resolveComponent("Search");
  const _component_Pagination = vue.resolveComponent("Pagination");

  return (vue.openBlock(), vue.createElementBlock("div", null, [
    vue.renderSlot(_ctx.$slots, "search", {}, () => [
      vue.createVNode(_component_Search, {
        table: _ctx.table,
        placeholder: _ctx.searchPlaceholder
      }, null, 8 /* PROPS */, ["table", "placeholder"])
    ]),
    vue.createElementVNode("div", _hoisted_1$e, [
      vue.renderSlot(_ctx.$slots, "default"),
      vue.renderSlot(_ctx.$slots, "footer", {}, () => [
        vue.createElementVNode("div", _hoisted_2$b, [
          vue.createVNode(_component_Pagination, { table: _ctx.table }, null, 8 /* PROPS */, ["table"]),
          vue.createElementVNode("div", _hoisted_3$8, vue.toDisplayString(_ctx.table.fromItem) + "-" + vue.toDisplayString(_ctx.table.toItem) + "/" + vue.toDisplayString(_ctx.table.totalItems), 1 /* TEXT */)
        ])
      ])
    ]),
    vue.renderSlot(_ctx.$slots, "pagination")
  ]))
}

script$h.render = render$e;
script$h.__file = "packages/admin-vue3/src/ui/Index.vue";

const _hoisted_1$d = ["value"];
var script$g = /*#__PURE__*/ vue.defineComponent({
    props: {
        modelValue: {},
        options: {
            type: Array,
            required: true,
        },
    },
    emits: ['update:modelValue'],
    setup(__props, { emit }) {
        const props = __props;
        const value = vue.ref(props.modelValue);
        vue.watch([value], () => emit('update:modelValue', value.value));
        return (_ctx, _cache) => {
            return vue.withDirectives((vue.openBlock(), vue.createElementBlock("select", vue.mergeProps(_ctx.$attrs, {
                "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => ((value).value = $event))
            }), [
                (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(__props.options, (option) => {
                    return (vue.openBlock(), vue.createElementBlock("option", {
                        key: option.value,
                        value: option.value
                    }, vue.toDisplayString(option.label), 9 /* TEXT, PROPS */, _hoisted_1$d));
                }), 128 /* KEYED_FRAGMENT */))
            ], 16 /* FULL_PROPS */)), [
                [vue.vModelSelect, value.value]
            ]);
        };
    }
});

script$g.__file = "packages/admin-vue3/src/ui/Select.vue";

var script$f = vue.defineComponent({
    components: {
        TransitionRoot: vue$1.TransitionRoot,
        TransitionChild: vue$1.TransitionChild,
        Dialog: vue$1.Dialog,
        DialogOverlay: vue$1.DialogOverlay,
        DialogTitle: vue$1.DialogTitle,
    },
    props: {
        open: {
            type: Boolean,
            required: true,
        },
    },
});

const _hoisted_1$c = { class: "fixed top-0 right-0 z-10 w-64 h-full mt-6 bg-white border-l border-gray-300 shadow pt-14" };
const _hoisted_2$a = { class: "min-h-screen text-center" };
const _hoisted_3$7 = { class: "inline-block w-full max-w-md overflow-y-scroll text-left transition-all transform" };
const _hoisted_4$4 = /*#__PURE__*/vue.createElementVNode("svg", {
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24",
  width: "24",
  height: "24"
}, [
  /*#__PURE__*/vue.createElementVNode("path", {
    fill: "none",
    d: "M0 0h24v24H0z"
  }),
  /*#__PURE__*/vue.createElementVNode("path", { d: "M7.828 11H20v2H7.828l5.364 5.364-1.414 1.414L4 12l7.778-7.778 1.414 1.414z" })
], -1 /* HOISTED */);
const _hoisted_5$3 = [
  _hoisted_4$4
];

function render$d(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_DialogOverlay = vue.resolveComponent("DialogOverlay");
  const _component_TransitionChild = vue.resolveComponent("TransitionChild");
  const _component_Dialog = vue.resolveComponent("Dialog");
  const _component_TransitionRoot = vue.resolveComponent("TransitionRoot");

  return (vue.openBlock(), vue.createBlock(_component_TransitionRoot, {
    show: _ctx.open,
    as: "template",
    enter: "transition-all duration-75",
    "enter-to": "opacity-100",
    leave: "transition-all duration-150",
    "enter-from": "transform translate-x-full",
    "leave-from": "transformtranslate-x-full",
    "leave-to": "transform translate-x-full"
  }, {
    default: vue.withCtx(() => [
      vue.createVNode(_component_Dialog, vue.mergeProps({ as: "div" }, _ctx.$attrs, { open: _ctx.open }), {
        default: vue.withCtx(() => [
          vue.createElementVNode("div", _hoisted_1$c, [
            vue.createElementVNode("aside", _hoisted_2$a, [
              vue.createVNode(_component_TransitionChild, {
                as: "template",
                enter: "duration-300 ease-out",
                "enter-from": "opacity-0",
                "enter-to": "opacity-100",
                leave: "duration-200 ease-in",
                "leave-from": "opacity-100",
                "leave-to": "opacity-0"
              }, {
                default: vue.withCtx(() => [
                  vue.createVNode(_component_DialogOverlay, { class: "fixed inset-0" })
                ]),
                _: 1 /* STABLE */
              }),
              vue.createVNode(_component_TransitionChild, {
                as: "template",
                enter: "duration-300 ease-out",
                "enter-from": "opacity-0 scale-95",
                "enter-to": "opacity-100 scale-100",
                leave: "duration-200 ease-in",
                "leave-from": "opacity-100 scale-100",
                "leave-to": "opacity-0 scale-95"
              }, {
                default: vue.withCtx(() => [
                  vue.createElementVNode("div", _hoisted_3$7, [
                    vue.createElementVNode("button", {
                      onClick: _cache[0] || (_cache[0] = $event => (_ctx.$emit('close', false)))
                    }, _hoisted_5$3),
                    vue.renderSlot(_ctx.$slots, "default")
                  ])
                ]),
                _: 3 /* FORWARDED */
              })
            ])
          ])
        ]),
        _: 3 /* FORWARDED */
      }, 16 /* FULL_PROPS */, ["open"])
    ]),
    _: 3 /* FORWARDED */
  }, 8 /* PROPS */, ["show"]))
}

script$f.render = render$d;
script$f.__file = "packages/admin-vue3/src/ui/Sidebar.vue";

const _hoisted_1$b = { key: 0 };
const _hoisted_2$9 = { key: 1 };
var script$e = /*#__PURE__*/ vue.defineComponent({
    props: {
        table: {
            type: Object,
            required: false,
        },
        sortBy: {
            type: String,
            required: false,
        },
    },
    setup(__props) {
        const props = __props;
        const isSortable = vue.computed(() => !!props.sortBy && !!props.table);
        const applySort = () => {
            if (!isSortable) {
                return;
            }
            if (!props.table.isSortedBy(props.sortBy)) {
                console.log('Add new (asc)');
                props.table.addSortBy(props.sortBy);
            }
            else if (props.table.isSortedBy(props.sortBy, 'asc')) {
                console.log('Change new (desc)');
                props.table.addSortBy(props.sortBy, 'desc');
            }
            else {
                console.log('Remove');
                props.table.removeSortBy(props.sortBy);
            }
        };
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("th", {
                class: vue.normalizeClass(["pb-2 pl-6 font-light bg-white border-b text-gray border-gray slim", {
                        'cursor-pointer': vue.unref(isSortable),
                    }]),
                onClick: _cache[0] || (_cache[0] = ($event) => (applySort()))
            }, [
                vue.renderSlot(_ctx.$slots, "default"),
                (vue.unref(isSortable))
                    ? (vue.openBlock(), vue.createElementBlock(vue.Fragment, { key: 0 }, [
                        (__props.table.isSortedBy(__props.sortBy, 'desc'))
                            ? (vue.openBlock(), vue.createElementBlock("span", _hoisted_1$b, " DESC "))
                            : vue.createCommentVNode("v-if", true),
                        (__props.table.isSortedBy(__props.sortBy, 'asc'))
                            ? (vue.openBlock(), vue.createElementBlock("span", _hoisted_2$9, " ASC "))
                            : vue.createCommentVNode("v-if", true)
                    ], 64 /* STABLE_FRAGMENT */))
                    : vue.createCommentVNode("v-if", true)
            ], 2 /* CLASS */));
        };
    }
});

script$e.__file = "packages/admin-vue3/src/ui/Th.vue";

var script$d = vue.defineComponent({
    props: {
        slim: {
            type: Boolean,
            default: false,
        },
    },
});

function render$c(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createElementBlock("td", {
    class: vue.normalizeClass(["py-5 pl-6 pr-6", { slim: _ctx.slim }])
  }, [
    vue.renderSlot(_ctx.$slots, "default")
  ], 2 /* CLASS */))
}

script$d.render = render$c;
script$d.__file = "packages/admin-vue3/src/ui/Td.vue";

var script$c = vue.defineComponent({
    components: { Th: script$e, Td: script$d },
    props: {
        selectable: {
            type: Boolean,
            default: false,
        },
        table: {
            type: Object,
            required: true,
        },
        schema: {
            type: Array,
            required: false,
        },
    },
});

const _hoisted_1$a = { class: "table w-full" };
const _hoisted_2$8 = { class: "sticky top-0 text-left text-gray-700 bg-white thead" };

function render$b(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Th = vue.resolveComponent("Th");
  const _component_Td = vue.resolveComponent("Td");
  const _component_Tr = vue.resolveComponent("Tr");

  return (vue.openBlock(), vue.createElementBlock("table", _hoisted_1$a, [
    vue.createElementVNode("thead", _hoisted_2$8, [
      vue.renderSlot(_ctx.$slots, "thead", {}, () => [
        vue.createElementVNode("tr", null, [
          (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(_ctx.schema, (column, thKey) => {
            return (vue.openBlock(), vue.createBlock(_component_Th, {
              key: `th-${thKey}`,
              column: column,
              class: "pr-4 text-xs font-normal bg-white h-7"
            }, null, 8 /* PROPS */, ["column"]))
          }), 128 /* KEYED_FRAGMENT */))
        ])
      ])
    ]),
    vue.createElementVNode("tbody", null, [
      vue.renderSlot(_ctx.$slots, "tbody", {
        items: _ctx.table.items
      }, () => [
        (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(_ctx.table.items, (item, trKey) => {
          return (vue.openBlock(), vue.createBlock(_component_Tr, {
            key: `th-${trKey}`
          }, {
            default: vue.withCtx(() => [
              (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(_ctx.schema, (column, tdKey) => {
                return (vue.openBlock(), vue.createBlock(_component_Td, {
                  key: `td-${tdKey}`,
                  column: column,
                  item: item,
                  class: "py-4 pr-4"
                }, null, 8 /* PROPS */, ["column", "item"]))
              }), 128 /* KEYED_FRAGMENT */))
            ]),
            _: 2 /* DYNAMIC */
          }, 1024 /* DYNAMIC_SLOTS */))
        }), 128 /* KEYED_FRAGMENT */))
      ])
    ])
  ]))
}

var e=[],t=[];function n(n,r){if(n&&"undefined"!=typeof document){var a,s=!0===r.prepend?"prepend":"append",d=!0===r.singleTag,i="string"==typeof r.container?document.querySelector(r.container):document.getElementsByTagName("head")[0];if(d){var u=e.indexOf(i);-1===u&&(u=e.push(i)-1,t[u]={}),a=t[u]&&t[u][s]?t[u][s]:t[u][s]=c();}else a=c();65279===n.charCodeAt(0)&&(n=n.substring(1)),a.styleSheet?a.styleSheet.cssText+=n:a.appendChild(document.createTextNode(n));}function c(){var e=document.createElement("style");if(e.setAttribute("type","text/css"),r.attributes)for(var t=Object.keys(r.attributes),n=0;n<t.length;n++)e.setAttribute(t[n],r.attributes[t[n]]);var a="prepend"===s?"afterbegin":"beforeend";return i.insertAdjacentElement(a,e),e}}

var css$1 = "\n.table .slim {\n    width: 1%;\n    white-space: nowrap;\n}\n.table .thead {\n    box-shadow: inset 0px -1px 0px #e5eaef;\n}\n";
n(css$1,{});

script$c.render = render$b;
script$c.__file = "packages/admin-vue3/src/ui/Table.vue";

var script$b = /*#__PURE__*/ vue.defineComponent({
    setup(__props) {
        //
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("textarea", vue.normalizeProps(vue.guardReactiveProps(_ctx.$attrs)), "\n        <slot />\n    ", 16 /* FULL_PROPS */));
        };
    }
});

script$b.__file = "packages/admin-vue3/src/ui/Textarea.vue";

var script$a = vue.defineComponent({
//
});

const _hoisted_1$9 = { class: "hover:bg-gray-500 odd:bg-gray-100" };

function render$a(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createElementBlock("tr", _hoisted_1$9, [
    vue.renderSlot(_ctx.$slots, "default")
  ]))
}

script$a.render = render$a;
script$a.__file = "packages/admin-vue3/src/ui/Tr.vue";

var script$9 = vue.defineComponent({
    name: 'TransitionSlide',
    props: {
        to: {
            type: String,
            default: 'left',
        },
    },
    setup() {
        //
    },
});

function render$9(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createBlock(vue.Transition, {
    name: `slide-${_ctx.to}`
  }, {
    default: vue.withCtx(() => [
      vue.renderSlot(_ctx.$slots, "default")
    ]),
    _: 3 /* FORWARDED */
  }, 8 /* PROPS */, ["name"]))
}

var css = "\n.slide-up-enter-active,\n.slide-down-enter-active,\n.slide-left-enter-active,\n.slide-right-enter-active {\n    transition: all 0.1s ease;\n}\n.slide-up-leave-active,\n.slide-down-leave-active,\n.slide-left-leave-active,\n.slide-right-leave-active {\n    transition: all 0.1s ease;\n}\n.slide-up-enter-from,\n.slide-up-leave-to {\n    transform: translateY(100%);\n}\n.slide-down-enter-from,\n.slide-down-leave-to {\n    transform: translateY(-100%);\n}\n.slide-left-enter-from,\n.slide-left-leave-to {\n    transform: translateX(100%);\n}\n.slide-right-enter-from,\n.slide-right-leave-to {\n    transform: translateX(-100%);\n}\n";
n(css,{});

script$9.render = render$9;
script$9.__file = "packages/admin-vue3/src/transitions/TransitionSlide.vue";

var script$8 = vue.defineComponent({
    setup() { },
});

const _hoisted_1$8 = {
  width: "100",
  viewBox: "0 0 889 263",
  xmlns: "http://www.w3.org/2000/svg",
  "xml:space": "preserve",
  "fill-rule": "evenodd",
  "clip-rule": "evenodd",
  "stroke-linejoin": "round",
  "stroke-miterlimit": "2"
};
const _hoisted_2$7 = /*#__PURE__*/vue.createStaticVNode("<g transform=\"translate(-204.96 -204.96)\"><path d=\"M204.96 368.93c0 22.64 18.35 40.99 40.99 40.99s40.99-18.35 40.99-40.99V245.95h-81.98v122.98Z\" fill=\"#4951f2\" fill-rule=\"nonzero\"></path><path d=\"M204.96 327.94c0 22.64 18.35 40.99 40.99 40.99s40.99-18.35 40.99-40.99v-81.98h-81.98v81.98Z\" fill=\"#40ffa4\" fill-opacity=\".42\" fill-rule=\"nonzero\"></path><path d=\"M204.96 286.94c0 22.64 18.35 40.99 40.99 40.99s40.99-18.35 40.99-40.99v-40.99h-81.98v40.99Z\" fill=\"#40ffa4\" fill-opacity=\".42\" fill-rule=\"nonzero\"></path><circle cx=\"245.95\" cy=\"245.95\" r=\"40.99\" fill=\"#40ffa4\"></circle><circle cx=\"332.48\" cy=\"426.66\" r=\"40.99\" fill=\"#4951f2\"></circle><path fill=\"#fff\" d=\"M459.11 237.6h23.11v130.76h-23.11zM507.77 270.29h23.11v98.07h-23.11z\"></path><path d=\"M519.39 231.28c-3.66 0-6.81 1.22-9.45 3.67-2.64 2.45-3.96 5.42-3.96 8.91 0 3.45 1.31 6.4 3.93 8.84 2.62 2.45 5.78 3.67 9.48 3.67 3.66 0 6.8-1.22 9.42-3.67s3.93-5.39 3.93-8.84c0-3.49-1.31-6.46-3.93-8.91s-5.76-3.67-9.42-3.67ZM600.52 349.91c-1.21.22-2.54.32-3.99.32-1.92 0-3.66-.3-5.24-.89-1.57-.59-2.84-1.71-3.8-3.35-.96-1.64-1.44-4.01-1.44-7.12v-50.7h19.35v-17.88h-19.35v-23.5h-23.11v23.5h-13.92v17.88h13.92v54.53c-.04 6.13 1.29 11.24 3.99 15.32 2.7 4.09 6.37 7.1 11.01 9.03 4.64 1.94 9.85 2.82 15.64 2.65 3.28-.08 6.05-.38 8.33-.89 2.28-.51 4.03-.98 5.27-1.4l-3.89-18.07c-.63.16-1.56.35-2.77.57ZM677.12 312.43l-16.73-3.58c-4.98-1.15-8.54-2.62-10.69-4.41-2.15-1.79-3.2-4.11-3.16-6.96-.04-3.32 1.56-6.02 4.82-8.11 3.26-2.09 7.29-3.13 12.1-3.13 3.58 0 6.6.57 9.07 1.72 2.47 1.15 4.44 2.66 5.91 4.53 1.47 1.87 2.5 3.87 3.1 6l21.07-2.3c-1.58-8.34-5.68-14.96-12.29-19.86-6.62-4.89-15.68-7.34-27.17-7.34-7.83 0-14.74 1.22-20.72 3.67-5.98 2.45-10.64 5.9-13.98 10.34-3.34 4.45-4.99 9.7-4.95 15.74-.04 7.15 2.19 13.06 6.7 17.72 4.51 4.66 11.47 7.97 20.88 9.93l16.73 3.51c4.51.98 7.84 2.38 9.99 4.21 2.15 1.83 3.22 4.15 3.22 6.96 0 3.32-1.67 6.11-5.01 8.37-3.34 2.25-7.75 3.38-13.25 3.38-5.32 0-9.64-1.13-12.96-3.38-3.32-2.26-5.49-5.6-6.51-10.03l-22.54 2.17c1.4 9.03 5.77 16.06 13.09 21.1 7.32 5.04 16.99 7.56 28.99 7.56 8.17 0 15.41-1.32 21.7-3.96 6.3-2.64 11.23-6.31 14.78-11.02 3.55-4.7 5.35-10.14 5.4-16.31-.05-7.02-2.33-12.7-6.86-17.05-4.55-4.3-11.45-7.47-20.73-9.47ZM767.87 349.91c-1.21.22-2.54.32-3.99.32-1.91 0-3.66-.3-5.24-.89-1.57-.59-2.84-1.71-3.8-3.35-.96-1.64-1.44-4.01-1.44-7.12v-50.7h19.35v-17.88H753.4v-23.5h-23.1v23.5h-13.92v17.88h13.92v54.53c-.04 6.13 1.29 11.24 3.99 15.32 2.7 4.09 6.37 7.1 11.01 9.03 4.64 1.94 9.86 2.82 15.64 2.65 3.28-.08 6.05-.38 8.33-.89 2.28-.51 4.03-.98 5.27-1.4l-3.89-18.07c-.64.16-1.56.35-2.78.57ZM861.01 276.13c-3.87-2.53-8.15-4.35-12.83-5.46a60.982 60.982 0 0 0-14.11-1.66c-6.86 0-13.11 1.01-18.77 3.03-5.66 2.02-10.45 5.05-14.37 9.07-3.92 4.02-6.73 9.01-8.43 14.97l21.58 3.06c1.15-3.36 3.37-6.28 6.67-8.75 3.3-2.47 7.78-3.7 13.44-3.7 5.36 0 9.47 1.32 12.32 3.96 2.85 2.64 4.28 6.36 4.28 11.17v.38c0 2.21-.82 3.84-2.46 4.88-1.64 1.04-4.25 1.81-7.82 2.3-3.58.49-8.24 1.03-13.98 1.63-4.77.51-9.37 1.33-13.82 2.46-4.45 1.13-8.44 2.78-11.97 4.95-3.53 2.17-6.32 5.07-8.37 8.69-2.04 3.62-3.06 8.19-3.06 13.73 0 6.43 1.44 11.83 4.31 16.22 2.87 4.39 6.79 7.69 11.75 9.93 4.96 2.24 10.55 3.35 16.76 3.35 5.11 0 9.56-.71 13.38-2.14 3.81-1.43 6.98-3.32 9.51-5.68 2.53-2.36 4.5-4.9 5.91-7.63h.76v13.47h22.22v-65.64c0-6.51-1.18-11.94-3.54-16.28-2.37-4.34-5.49-7.78-9.36-10.31Zm-10.16 57.05c0 3.62-.93 6.96-2.78 10.03-1.85 3.06-4.48 5.52-7.88 7.37-3.41 1.85-7.43 2.78-12.07 2.78-4.81 0-8.77-1.08-11.88-3.26-3.11-2.18-4.66-5.38-4.66-9.64 0-2.98.78-5.42 2.36-7.31 1.57-1.89 3.72-3.37 6.45-4.44 2.72-1.06 5.81-1.83 9.26-2.3 1.53-.21 3.34-.47 5.43-.77 2.09-.3 4.19-.64 6.32-1.02s4.06-.83 5.78-1.34c1.72-.51 2.95-1.06 3.67-1.66v11.56ZM929.52 291.45c3.58-2.53 7.73-3.8 12.45-3.8 5.57 0 10.03 1.59 13.38 4.76 3.34 3.17 5.46 7.12 6.35 11.84h22.09c-.51-7.07-2.6-13.25-6.26-18.55-3.66-5.3-8.57-9.41-14.71-12.32-6.15-2.91-13.21-4.37-21.17-4.37-9.58 0-17.87 2.14-24.87 6.42-7 4.28-12.42 10.24-16.25 17.88-3.83 7.64-5.75 16.44-5.75 26.4 0 9.92 1.89 18.68 5.65 26.28 3.77 7.6 9.15 13.55 16.15 17.84 7 4.3 15.4 6.45 25.19 6.45 8.22 0 15.37-1.5 21.45-4.5 6.09-3 10.9-7.17 14.43-12.51 3.53-5.34 5.58-11.48 6.13-18.42H961.7c-.68 3.53-1.94 6.53-3.77 9-1.83 2.47-4.1 4.35-6.8 5.65-2.7 1.3-5.76 1.95-9.16 1.95-4.81 0-8.99-1.29-12.55-3.86-3.55-2.57-6.31-6.26-8.27-11.04-1.96-4.79-2.94-10.52-2.94-17.21 0-6.6.99-12.26 2.97-16.98 1.99-4.74 4.77-8.37 8.34-10.91ZM1066.17 368.36h27.64l-40.25-55.74 38.02-42.33h-27.01l-35.24 39.39h-1.6V237.6h-23.11v130.76h23.11v-32.97l8.41-9.01 30.03 41.98Z\" fill=\"#fff\" fill-rule=\"nonzero\"></path></g>", 1);
const _hoisted_3$6 = [
  _hoisted_2$7
];

function render$8(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$8, _hoisted_3$6))
}

script$8.render = render$8;
script$8.__file = "packages/admin-vue3/src/svg/Logo.vue";

var script$7 = vue.defineComponent({});

const _hoisted_1$7 = { class: "text-white relative w-5 h-4" };
const _hoisted_2$6 = /*#__PURE__*/vue.createElementVNode("div", { class: "absolute left-0 top-0 w-full h-0.5 bg-white" }, null, -1 /* HOISTED */);
const _hoisted_3$5 = /*#__PURE__*/vue.createElementVNode("div", { class: "absolute left-0 top-1/2 w-full h-0.5 bg-white" }, null, -1 /* HOISTED */);
const _hoisted_4$3 = /*#__PURE__*/vue.createElementVNode("div", { class: "absolute left-0 top-full w-full h-0.5 bg-white" }, null, -1 /* HOISTED */);
const _hoisted_5$2 = [
  _hoisted_2$6,
  _hoisted_3$5,
  _hoisted_4$3
];

function render$7(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createElementBlock("button", _hoisted_1$7, _hoisted_5$2))
}

script$7.render = render$7;
script$7.__file = "packages/admin-vue3/src/layouts/default/DefaultLayoutBurger.vue";

var script$6 = vue.defineComponent({
    components: { DefaultLayoutBurger: script$7, Logo: script$8 },
    setup() {
        //
    },
});

const _hoisted_1$6 = { class: "flex items-center pt-2 pb-20 justify-between" };
const _hoisted_2$5 = { class: "flex items-center gap-4" };

function render$6(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Logo = vue.resolveComponent("Logo");
  const _component_DefaultLayoutBurger = vue.resolveComponent("DefaultLayoutBurger");

  return (vue.openBlock(), vue.createElementBlock("header", null, [
    vue.createElementVNode("div", _hoisted_1$6, [
      vue.renderSlot(_ctx.$slots, "logo", {}, () => [
        vue.createVNode(_component_Logo)
      ]),
      vue.createElementVNode("div", _hoisted_2$5, [
        vue.renderSlot(_ctx.$slots, "default", {}, () => [
          vue.createVNode(_component_DefaultLayoutBurger)
        ])
      ])
    ])
  ]))
}

script$6.render = render$6;
script$6.__file = "packages/admin-vue3/src/layouts/default/DefaultLayoutHeader.vue";

var script$5 = vue.defineComponent({
    components: { TransitionSlide: script$9, DefaultLayoutHeader: script$6 },
    name: 'Layout',
    setup() {
        const sidebar = vue.reactive({
            isOpen: false,
            show() {
                this.isOpen = true;
            },
            close() {
                this.isOpen = false;
            },
            toggle() {
                this.isOpen = !this.isOpen;
            },
        });
        return {
            sidebar,
        };
    },
});

const _hoisted_1$5 = { class: "flex w-screen" };
const _hoisted_2$4 = { class: "z-10 w-64 h-screen p-4 overflow-y-scroll text-white bg-blue-900" };
const _hoisted_3$4 = {
  key: 0,
  class: "w-64 h-screen p-4 bg-white border-r border-gray-300 shadow"
};
const _hoisted_4$2 = { class: "flex flex-col flex-1 h-screen overflow-y-scroll" };
const _hoisted_5$1 = { class: "sticky top-0 z-20 w-full bg-white" };
const _hoisted_6 = { class: "flex items-center justify-between h-12 px-6 border-b border-gray-300" };
const _hoisted_7 = { class: "flex items-center justify-between px-6 text-xs border-b border-gray-300 text-gray" };
const _hoisted_8 = { class: "relative flex-1 overflow-y-scroll" };

function render$5(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_DefaultLayoutHeader = vue.resolveComponent("DefaultLayoutHeader");

  return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$5, [
    vue.createElementVNode("aside", _hoisted_2$4, [
      vue.renderSlot(_ctx.$slots, "header", {}, () => [
        vue.createVNode(_component_DefaultLayoutHeader)
      ]),
      vue.createElementVNode("nav", null, [
        vue.renderSlot(_ctx.$slots, "sidebar", { sidebar: _ctx.sidebar })
      ])
    ]),
    (_ctx.sidebar.isOpen)
      ? (vue.openBlock(), vue.createElementBlock("aside", _hoisted_3$4, [
          vue.renderSlot(_ctx.$slots, "sidebar-secondary")
        ]))
      : vue.createCommentVNode("v-if", true),
    vue.createElementVNode("div", _hoisted_4$2, [
      vue.createElementVNode("header", _hoisted_5$1, [
        vue.createElementVNode("nav", _hoisted_6, [
          vue.renderSlot(_ctx.$slots, "header", { sidebar: _ctx.sidebar })
        ]),
        vue.createElementVNode("nav", _hoisted_7, [
          vue.renderSlot(_ctx.$slots, "header-secondary", { sidebar: _ctx.sidebar })
        ])
      ]),
      vue.createElementVNode("main", _hoisted_8, [
        vue.renderSlot(_ctx.$slots, "default", { sidebar: _ctx.sidebar })
      ])
    ])
  ]))
}

script$5.render = render$5;
script$5.__file = "packages/admin-vue3/src/layouts/default/DefaultLayout.vue";

var script$4 = vue.defineComponent({
    setup() { },
});

const _hoisted_1$4 = { class: "flex w-screen h-screen" };
const _hoisted_2$3 = { class: "grid w-full h-full grid-cols-12" };
const _hoisted_3$3 = { class: "flex flex-col items-center justify-center col-span-12 gap-16 bg-white md:col-span-6" };
const _hoisted_4$1 = { class: "w-full lg:w-1/2 px-12 lg:px-0" };
const _hoisted_5 = { class: "flex items-center justify-center col-span-12 text-white bg-blue-900 md:col-span-6" };

function render$4(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Logo = vue.resolveComponent("Logo");

  return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$4, [
    vue.createElementVNode("div", _hoisted_2$3, [
      vue.createElementVNode("div", _hoisted_3$3, [
        vue.createElementVNode("div", _hoisted_4$1, [
          vue.renderSlot(_ctx.$slots, "default")
        ])
      ]),
      vue.createElementVNode("div", _hoisted_5, [
        vue.createVNode(_component_Logo)
      ])
    ])
  ]))
}

script$4.render = render$4;
script$4.__file = "packages/admin-vue3/src/layouts/guest/GuestLayout.vue";

var script$3 = vue.defineComponent({
    components: { Input: macrameVue3.Input },
    props: {
        errors: {
            type: [Array, String],
            required: false,
        },
    },
    setup() {
        //
    },
});

const _hoisted_1$3 = { key: 0 };

function render$3(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Input = vue.resolveComponent("Input");

  return (vue.openBlock(), vue.createElementBlock("div", null, [
    vue.createVNode(_component_Input, vue.mergeProps({ class: "w-full py-2 text-gray-900 border-b outline-none border-gray" }, _ctx.$attrs), null, 16 /* FULL_PROPS */),
    (_ctx.errors)
      ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$3, [
          (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(typeof _ctx.errors === 'string'
                    ? [_ctx.errors]
                    : _ctx.errors, (error, key) => {
            return (vue.openBlock(), vue.createElementBlock("div", {
              key: key,
              class: "text-red"
            }, vue.toDisplayString(error), 1 /* TEXT */))
          }), 128 /* KEYED_FRAGMENT */))
        ]))
      : vue.createCommentVNode("v-if", true)
  ]))
}

script$3.render = render$3;
script$3.__file = "packages/admin-vue3/src/layouts/guest/GuestLayoutInput.vue";

var script$2 = vue.defineComponent({
    components: { GuestLayout: script$4, Input: script$3, Checkbox: script$n, Button: script$v },
    props: {
        submitRoute: {
            type: String,
            required: true,
        },
        forgotPasswordRoute: {
            type: String,
        },
        lang: {
            type: Object,
            default: {
                login: 'Login',
                email: 'Email',
                password: 'Password',
                remember: 'Remember Me',
                forgot_password: 'Forgot your password?',
            },
        },
    },
    setup({ submitRoute }) {
        const form = macrameVue3.useForm(submitRoute, { email: '', password: '', remember: false }, { method: 'post' });
        return { form };
    },
});

const _hoisted_1$2 = { class: "flex justify-between" };
const _hoisted_2$2 = ["href"];
const _hoisted_3$2 = { class: "flex justify-center mt-5" };

function render$2(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Input = vue.resolveComponent("Input");
  const _component_Checkbox = vue.resolveComponent("Checkbox");
  const _component_Button = vue.resolveComponent("Button");
  const _component_GuestLayout = vue.resolveComponent("GuestLayout");

  return (vue.openBlock(), vue.createBlock(_component_GuestLayout, null, {
    default: vue.withCtx(() => [
      vue.createElementVNode("form", {
        onSubmit: _cache[3] || (_cache[3] = vue.withModifiers((...args) => (_ctx.form.submit && _ctx.form.submit(...args)), ["prevent"]))
      }, [
        vue.createVNode(_component_Input, {
          autofocus: "",
          required: "",
          class: "mb-3",
          type: "email",
          autocomplete: "username",
          modelValue: _ctx.form.email,
          "onUpdate:modelValue": _cache[0] || (_cache[0] = $event => ((_ctx.form.email) = $event)),
          placeholder: _ctx.lang.email,
          errors: _ctx.form.errors?.email
        }, null, 8 /* PROPS */, ["modelValue", "placeholder", "errors"]),
        vue.createVNode(_component_Input, {
          required: "",
          class: "mb-3",
          type: "password",
          autocomplete: "username",
          modelValue: _ctx.form.password,
          "onUpdate:modelValue": _cache[1] || (_cache[1] = $event => ((_ctx.form.password) = $event)),
          placeholder: _ctx.lang.password,
          errors: _ctx.form.errors?.password
        }, null, 8 /* PROPS */, ["modelValue", "placeholder", "errors"]),
        vue.createElementVNode("div", _hoisted_1$2, [
          vue.createVNode(_component_Checkbox, {
            sm: "",
            label: _ctx.lang.remember,
            modelValue: _ctx.form.remember,
            "onUpdate:modelValue": _cache[2] || (_cache[2] = $event => ((_ctx.form.remember) = $event))
          }, null, 8 /* PROPS */, ["label", "modelValue"]),
          (_ctx.forgotPasswordRoute)
            ? (vue.openBlock(), vue.createElementBlock("a", {
                key: 0,
                href: _ctx.forgotPasswordRoute,
                class: "text-right"
              }, vue.toDisplayString(_ctx.lang.forgot_password), 9 /* TEXT, PROPS */, _hoisted_2$2))
            : vue.createCommentVNode("v-if", true)
        ]),
        vue.createElementVNode("div", _hoisted_3$2, [
          vue.createVNode(_component_Button, {
            class: vue.normalizeClass({ 'opacity-25': _ctx.form.processing }),
            disabled: _ctx.form.processing
          }, {
            default: vue.withCtx(() => [
              vue.createTextVNode(vue.toDisplayString(_ctx.lang.login), 1 /* TEXT */)
            ]),
            _: 1 /* STABLE */
          }, 8 /* PROPS */, ["class", "disabled"])
        ])
      ], 32 /* HYDRATE_EVENTS */)
    ]),
    _: 1 /* STABLE */
  }))
}

script$2.render = render$2;
script$2.__file = "packages/admin-vue3/src/pages/Login.vue";

var script$1 = vue.defineComponent({
    components: { GuestLayout: script$4, Input: script$3, Checkbox: script$n, Button: script$v },
    props: {
        submitRoute: {
            type: String,
            required: true,
        },
        lang: {
            type: Object,
            default: {
                message: 'Forgot your password? No problem. Just let us know your email address and we will email you a password reset link that will allow you to choose a new one.',
                email: 'Email',
                send_reset_link: 'Send Password Reset Link',
            },
        },
        status: String,
    },
    setup({ submitRoute }) {
        const form = macrameVue3.useForm(submitRoute, { email: '', password: '', remember: false }, { method: 'post' });
        return { form };
    },
});

const _hoisted_1$1 = { class: "mb-3 text-sm text-gray-600" };
const _hoisted_2$1 = {
  key: 0,
  class: "mb-4 font-medium text-sm text-green-600"
};
const _hoisted_3$1 = { class: "flex justify-center mt-5" };

function render$1(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Input = vue.resolveComponent("Input");
  const _component_Button = vue.resolveComponent("Button");
  const _component_GuestLayout = vue.resolveComponent("GuestLayout");

  return (vue.openBlock(), vue.createBlock(_component_GuestLayout, null, {
    default: vue.withCtx(() => [
      vue.createElementVNode("div", _hoisted_1$1, vue.toDisplayString(_ctx.lang.message), 1 /* TEXT */),
      (_ctx.status)
        ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_2$1, vue.toDisplayString(_ctx.status), 1 /* TEXT */))
        : vue.createCommentVNode("v-if", true),
      vue.createElementVNode("form", {
        onSubmit: _cache[1] || (_cache[1] = vue.withModifiers((...args) => (_ctx.form.submit && _ctx.form.submit(...args)), ["prevent"]))
      }, [
        vue.createVNode(_component_Input, {
          autofocus: "",
          required: "",
          class: "mb-3",
          type: "email",
          autocomplete: "username",
          modelValue: _ctx.form.email,
          "onUpdate:modelValue": _cache[0] || (_cache[0] = $event => ((_ctx.form.email) = $event)),
          placeholder: _ctx.lang.email,
          errors: _ctx.form.errors?.email
        }, null, 8 /* PROPS */, ["modelValue", "placeholder", "errors"]),
        vue.createElementVNode("div", _hoisted_3$1, [
          vue.createVNode(_component_Button, {
            class: vue.normalizeClass({ 'opacity-25': _ctx.form.processing }),
            disabled: _ctx.form.processing
          }, {
            default: vue.withCtx(() => [
              vue.createTextVNode(vue.toDisplayString(_ctx.lang.send_reset_link), 1 /* TEXT */)
            ]),
            _: 1 /* STABLE */
          }, 8 /* PROPS */, ["class", "disabled"])
        ])
      ], 32 /* HYDRATE_EVENTS */)
    ]),
    _: 1 /* STABLE */
  }))
}

script$1.render = render$1;
script$1.__file = "packages/admin-vue3/src/pages/ForgotPassword.vue";

var script = vue.defineComponent({
    components: { GuestLayout: script$4, Input: script$3, Checkbox: script$n, Button: script$v },
    props: {
        submitRoute: {
            type: String,
            required: true,
        },
        email: {
            type: String,
            required: true,
        },
        token: {
            type: String,
            required: true,
        },
        lang: {
            type: Object,
            default: {
                password: 'Password',
                password_confirmation: 'Repeat password',
                email: 'Email',
                reset_password: 'Reset Password',
            },
        },
        status: String,
    },
    setup({ submitRoute, token, email }) {
        const form = macrameVue3.useForm(submitRoute, {
            token: token,
            email: email,
            password: '',
            password_confirmation: '',
        }, {
            method: 'post',
            onFinish() {
                console.log('foo');
            },
        });
        return { form };
    },
});

const _hoisted_1 = { class: "mb-3 text-sm text-gray-600" };
const _hoisted_2 = {
  key: 0,
  class: "mb-4 font-medium text-sm text-green-600"
};
const _hoisted_3 = {
  key: 0,
  class: "mb-4 text-red"
};
const _hoisted_4 = { class: "flex justify-center mt-5" };

function render(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Input = vue.resolveComponent("Input");
  const _component_Button = vue.resolveComponent("Button");
  const _component_GuestLayout = vue.resolveComponent("GuestLayout");

  return (vue.openBlock(), vue.createBlock(_component_GuestLayout, null, {
    default: vue.withCtx(() => [
      vue.createElementVNode("div", _hoisted_1, vue.toDisplayString(_ctx.lang.message), 1 /* TEXT */),
      (_ctx.status)
        ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_2, vue.toDisplayString(_ctx.status), 1 /* TEXT */))
        : vue.createCommentVNode("v-if", true),
      vue.createElementVNode("form", {
        onSubmit: _cache[3] || (_cache[3] = vue.withModifiers((...args) => (_ctx.form.submit && _ctx.form.submit(...args)), ["prevent"]))
      }, [
        vue.createVNode(_component_Input, {
          autofocus: "",
          required: "",
          class: "mb-3",
          type: "email",
          autocomplete: "username",
          modelValue: _ctx.form.email,
          "onUpdate:modelValue": _cache[0] || (_cache[0] = $event => ((_ctx.form.email) = $event)),
          placeholder: _ctx.lang.email,
          errors: _ctx.form.errors?.email
        }, null, 8 /* PROPS */, ["modelValue", "placeholder", "errors"]),
        vue.createVNode(_component_Input, {
          required: "",
          class: "mb-3",
          type: "password",
          autocomplete: "new-password",
          modelValue: _ctx.form.password,
          "onUpdate:modelValue": _cache[1] || (_cache[1] = $event => ((_ctx.form.password) = $event)),
          placeholder: _ctx.lang.password,
          errors: _ctx.form.errors?.password
        }, null, 8 /* PROPS */, ["modelValue", "placeholder", "errors"]),
        vue.createVNode(_component_Input, {
          required: "",
          class: "mb-3",
          type: "password",
          autocomplete: "new-password",
          modelValue: _ctx.form.password_confirmation,
          "onUpdate:modelValue": _cache[2] || (_cache[2] = $event => ((_ctx.form.password_confirmation) = $event)),
          placeholder: _ctx.lang.password_confirmation,
          errors: _ctx.form.errors?.password_confirmation
        }, null, 8 /* PROPS */, ["modelValue", "placeholder", "errors"]),
        (_ctx.form.errors?.token)
          ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_3, vue.toDisplayString(_ctx.form.errors.token), 1 /* TEXT */))
          : vue.createCommentVNode("v-if", true),
        vue.createElementVNode("div", _hoisted_4, [
          vue.createVNode(_component_Button, {
            class: vue.normalizeClass({ 'opacity-25': _ctx.form.processing }),
            disabled: _ctx.form.processing
          }, {
            default: vue.withCtx(() => [
              vue.createTextVNode(vue.toDisplayString(_ctx.lang.reset_password), 1 /* TEXT */)
            ]),
            _: 1 /* STABLE */
          }, 8 /* PROPS */, ["class", "disabled"])
        ])
      ], 32 /* HYDRATE_EVENTS */)
    ]),
    _: 1 /* STABLE */
  }))
}

script.render = render;
script.__file = "packages/admin-vue3/src/pages/ResetPassword.vue";

const plugin = {
    install(app) {
        app.component('UiCard', script$u);
        app.component('UiToggle', script$t);
        app.component('UiButton', script$v);
        app.component('UiBadge', script$s);
        app.component('UiForm', script$r);
        app.component('UiModal', script$o);
        app.component('UiCheckbox', script$n);
        app.component('UiFormCheckboxes', script$m);
        app.component('UiFormSelect', FormSelect);
        app.component('UiFormTextarea', FormTextarea);
        app.component('UiRadioGroup', script$l);
        app.component('UiIndex', script$h);
        app.component('UiInput', script$j);
        app.component('UiSelect', script$g);
        app.component('UiSidebar', script$f);
        app.component('UiPagination', script$k);
        app.component('UiTable', script$c);
        app.component('UiTextarea', script$b);
    },
};
const AuthPages = {
    "Auth/Login": script$2,
    "Auth/ForgotPassword": script$1,
    "Auth/ResetPassword": script,
};
const Pages = { ...AuthPages };

exports.AuthPages = AuthPages;
exports.Badge = script$s;
exports.Button = script$v;
exports.Card = script$u;
exports.Checkbox = script$n;
exports.DefaultLayout = script$5;
exports.DefaultLayoutBurger = script$7;
exports.DefaultLayoutHeader = script$6;
exports.Form = script$r;
exports.FormField = script$p;
exports.FormFieldLabel = script$q;
exports.GuestLayout = script$4;
exports.GuestLayoutInput = script$3;
exports.Index = script$h;
exports.Input = script$j;
exports.Modal = script$o;
exports.Pages = Pages;
exports.Pagination = script$k;
exports.Search = script$i;
exports.Select = script$g;
exports.Sidebar = script$f;
exports.Table = script$c;
exports.Td = script$d;
exports.Textarea = script$b;
exports.Th = script$e;
exports.Toggle = script$t;
exports.Tr = script$a;
exports.plugin = plugin;
